@@ -334,14 +334,10 @@ _SWITCH = (
     Keyword("yes", _IDENTBODYCHARS)
     | Keyword("true", _IDENTBODYCHARS)
     | Keyword("on", _IDENTBODYCHARS)
-    | Keyword("y", _IDENTBODYCHARS)
-    | Keyword("t", _IDENTBODYCHARS)
 ).set_parse_action(lambda: True) | (
     Keyword("no", _IDENTBODYCHARS)
     | Keyword("false", _IDENTBODYCHARS)
     | Keyword("off", _IDENTBODYCHARS)
-    | Keyword("n", _IDENTBODYCHARS)
-    | Keyword("f", _IDENTBODYCHARS)
 ).set_parse_action(lambda: False)
 _DIMENSIONS = (
     Literal("[").suppress() + common.number[0, 7] + Literal("]").suppress()
@@ -582,9 +578,11 @@ class Parsed(Mapping[Tuple[str, ...], Union[Data, StandaloneData, EllipsisType]]
 
         diff = len(content) - (end - start)
         for k, (s, d, e) in self._parsed.items():
-            if s > end:
+            if s >= end:
                 self._parsed[k] = (s + diff, d, e + diff)
             elif e > start:
+                self._parsed[k] = (s, d, end + diff)
+            elif s > start:
                 self._parsed[k] = (s, d, e + diff)
 
         self._parsed[keywords] = (start, data, end + diff)
